/**
 * Copyright (c) 2008-2012 EBM WebSourcing, 2012-2015 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.jaas;

import java.security.Principal;

/**
 * Check authorizations in Group principal.
 * 
 * @author Christophe HAMERLING - eBM WebSourcing
 * @since 1.0
 * 
 */
public class GroupPrincipal implements Principal {

    public static final GroupPrincipal ALL = new GroupPrincipal("*");

    private final String name;

    private transient int hash;

    /**
     * Creates a new instance of GroupPrincipal
     * 
     * @param name
     */
    public GroupPrincipal(String name) {
        if (name == null) {
            throw new IllegalArgumentException("Group Principal name can not be null");
        }
        this.name = name;
    }

    /*
     * (non-Javadoc)
     * 
     * @see java.security.Principal#getName()
     */
    public String getName() {
        return this.name;
    }

    /*
     * (non-Javadoc)
     * 
     * @see java.lang.Object#equals(java.lang.Object)
     */
    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if ((o == null) || (this.getClass() != o.getClass())) {
            return false;
        }

        final GroupPrincipal that = (GroupPrincipal) o;

        if (!this.name.equals(that.name)) {
            return false;
        }

        return true;
    }

    /*
     * (non-Javadoc)
     * 
     * @see java.lang.Object#hashCode()
     */
    @Override
    public int hashCode() {
        if (this.hash == 0) {
            this.hash = this.name.hashCode();
        }
        return this.hash;
    }

    /*
     * (non-Javadoc)
     * 
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        return this.name;
    }
}
